#
# Aura Engine API (https://gitlab.servus.at/aura/engine-api)
#
# Copyright (C) 2020 - The Aura Engine Team.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


import connexion
import six

from src.rest.models.play_log_entry import PlayLogEntry  # noqa: E501
from src.rest.models.playlist import Playlist  # noqa: E501
from src.rest import util

from src.service.playlist_service import playlistService
from src.service.track_service import trackService
from src.service.engine_service import engineService


def current_track():  # noqa: E501
    """Get current track

    Retrieves the currently playing track.  # noqa: E501


    :rtype: PlayLogEntry
    """
    return trackService.current_track()


def get_track(track_id):  # noqa: E501
    """Get a single track by ID

    Retrieves a single track by its ID.  # noqa: E501

    :param track_id: ID of the track-service entry
    :type track_id: int

    :rtype: PlayLogEntry
    """
    return trackService.get_track(track_id)


def list_tracks(offset=None, limit=None):  # noqa: E501
    """List recent tracks in the play-log

    Lists the most recent track-service entries.  # noqa: E501

    :param offset: The number of items to skip before starting to collect the result set
    :type offset: int
    :param limit: The numbers of items to return
    :type limit: int

    :rtype: List[PlayLogEntry]
    """
    return trackService.list_tracks(offset, limit)


def current_playlist():  # noqa: E501
    """Get current playlist

    Retrieves the currently playing playlist.  # noqa: E501


    :rtype: Playlist
    """
    return playlistService.current_playlist()


def next_playlist():  # noqa: E501
    """Get next playlist

    Retrieves the playlist playing next  # noqa: E501


    :rtype: Playlist
    """
    return playlistService.next_playlist()
